import java.util.Scanner;

/**
 * Main.
 * 
 * Liest die Parameter ein, gibt das Einstellbild aus und lässt dann das
 * Programm eine bestimmte Zeit lang laufen.
 * 
 * @author Stephan Bauer
 * @author Thomas Gradisnik
 * @version 1.0
 * 
 */

public class Main {

    /**
     * Der Anwendung können beim Starten zwei Parameter übergeben werden. Dies
     * sind die Breite und die Höhe des Fensters. Als Standardwerte werden 80/25
     * verwendet. Der Wert muss exakt mit der Konsolengröße übereinstimmen.
     * 
     * @param args
     *            Werden genau zwei Parameter übergeben so werden diese als
     *            Breite und Höhe verwendet. Diese müssen als int spezifiziert
     *            werden.
     */
    public static void main(String[] args) {

	/* Parameter */
	// Standardgröße
	int width = 80;
	int height = 25;

	// Mittlere Lebenszeit der Schneeflocken
	int lifetime = (int) (height * 1.0);

	// Anzahl an Schneeflocken
	int amount = width * height / 12;

	// Framerate
	int framerate = 6;

	// Laufzeit in Millisekunden
	int runtime = 120 * 1000;

	/* ******************** */

	if (args.length == 2) {
	    width = Integer.valueOf(args[0]);
	    height = Integer.valueOf(args[1]);
	}

	// Testbild ausgeben
	// Erzeugt ein Rechteck in der angegebenen Größe und 
	// schreibt den Text mittig in das Rechteck.
	String messages[] = { "Let it Snow!", "", "Press <Enter> to start." };

	for (int j = 0; j < height; j++) {
	    for (int i = 0; i < width; i++) {
		if (i == 0 || i == width - 1) {
		    System.out.print("o");
		} else if (j == 0 || j == height - 1) {
		    System.out.print("x");
		} else if (j >= (height - messages.length) / 2 && j < height - (height - messages.length + 1) / 2) {
		    int jnew = j - (height - messages.length) / 2;
		    if (i >= (width - messages[jnew].length()) / 2 && i < width - (width - messages[jnew].length() + 1) / 2) {
			System.out.print(messages[jnew].charAt(i - ((width - messages[jnew].length()) / 2)));
		    } else {
			System.out.print(" ");
		    }
		} else {
		    System.out.print(" ");
		}
	    }
	}

	new Scanner(System.in).nextLine();

	SnowflakeList list = new SnowflakeList(amount, width, height, lifetime);

	Renderer r = new Renderer(list, width, height);

	// Diese Schleife spiegelt den Programmablauf wieder.
	// Sie läuft über die angegebene Zeit und zeichnet so oft wie in der
	// framerate (pro Minute) spezifizert wurde das Bild neu. 
	// Danach wartet die Codeausführung mittels Thread.sleep().
	for (int i = 0; i < runtime / (1000 / framerate); i++) {

	    // Mittels der toString Methode des Renderer das Bild ausgebene
	    System.out.print(r);

	    // Bis zum nächsten Durchlauf warten
	    try {
		Thread.sleep(1000 / framerate);
	    } catch (InterruptedException e) {
		break;
	    }

	    // Schneeflocken fallen lassen
	    list.fall();

	}

    }

}
