/**
 * Snowflake.
 * 
 * Eine Schneeflocke. Verschiedene Methoden lassen die Schneeflocke schmelzen
 * oder bewegen sie.
 * 
 * @author Stephan Bauer
 * @author Thomas Gradisnik
 * @version 1.0
 * 
 */

public class Snowflake {

    private int x;
    private int y;
    private int lifetime;
    private char symbol;

    /**
     * Konstruktor.
     * 
     * Eine neue Schneeflocke initialisieren.
     * 
     * @param initx
     *            Anfangsposition in x-Richtung
     * @param inity
     *            Anfangsposition in y-Richtung
     * @param lifetime
     *            Lebensdauer
     * @param symbol
     *            Character, der die Schneeflocke darstellt
     */
    public Snowflake(int initx, int inity, int lifetime, char symbol) {

	this.x = initx;
	this.y = inity;
	this.lifetime = lifetime;
	this.symbol = symbol;

    }

    /**
     * Bewegt die Schneeflocke.
     * 
     * @param initx
     *            Bewegungs-Delta in x-Richtung
     * @param inity
     *            Bewegungs-Delta in y-Richtung
     */
    public void move(int dx, int dy) {

	this.x += dx;
	this.y += dy;

    }

    /**
     * Lässt die Schneeflocke langsam schmelzen.
     * 
     * Bei jedem Aufruf wird die Lebenszeit verringert. Solange die Lebenszeit
     * größer als 0 ist, gibt die Methode true zurück, ist ihre Lebenszeit
     * abgelaufen, gibt sie false zurück.
     * 
     * @return Lebenszeit größer 0
     */
    public boolean melt() {
	lifetime--;
	return (lifetime <= 0);
    }

    /**
     * Liefert die aktuelle Position in x-Richtung.
     * 
     * @return aktuelle x-Position
     */
    public int getX() {
	return x;
    }

    /**
     * Liefert die aktuelle Position in y-Richtung.
     * 
     * @return aktuelle y-Position
     */
    public int getY() {
	return y;
    }

    /**
     * String-Darstellung.
     * 
     * Die Methode gibt die String-Darstellung der Schneeflocke zurück, dafür
     * wird der gespeicherte Character entsprechend konvertiert.
     * 
     * @return Schneeflocke als String.
     */
    public String toString() {
	return String.valueOf(this.symbol);
    }

}
