public class Bruch {
	
	private int zaehler;
	private int nenner;
	
	/**
	* Konstruktor: Initialisiert diesen Bruch.
	*/
	public Bruch(int z, int n) {
	
		this.zaehler = z;
		this.nenner = n;
	
	}
	
	/**
	* @return eine lesbare Repräsentation dieses Bruchs.
	*/
	public String toString() {
		
		return this.zaehler + "/" + this.nenner;
		
	}
	
	/**
	* @return liefert das gekürzte Äquivalent zu diesem Bruch.
	*/
	public Bruch reduce() {
		
		int ggt = BruchRechner3.ggt(this.zaehler, this.nenner);
		ggt *= this.nenner < 0 ? -1 : 1;
		return new Bruch(this.zaehler/ggt, this.nenner/ggt);
		
	}
	
	//beste Möglichkeit:
	/**
	* Berechnet das Produkt von diesem Bruch und einem angegeben Bruch und 
	* liefert das Ergebnis als neuen Bruch zurück.
	*
	* @param b der zweite Operand für die Multiplikation
	* @return das Produkt
	*/
	public Bruch mult(Bruch b) {
	
		return new Bruch(this.zaehler*b.zaehler, this.nenner*b.nenner);
	
	}
	
	//Variante 1: Objekt ist veränderbar.
	//globale Seiteneffekte möglich!
	/**
	* Berechnet das Produkt von diesem Bruch und einem angegeben Bruch.
	* Dabei wird dieser Bruch zum Ergebnis der Multiplikation. (Diese
	* Operation ändert dieses Bruch-Objekt.)
	*
	* @param b der zweite Operand für die Multiplikation
	*/
	/* 
	public void mult(Bruch b) {
	
		 this.zaehler*=b.zaehler;
		 this.nenner*=b.nenner;
	
	}
	*/
	
	//Variante 2: mit static-Methode
	//nicht auf dieses Objekt bezogen, daher static. Prozeduraler Stil. //Methode könnte abgesehen von der Sichtbarkeit der Objektvariablen
	//auch in andere Klassen verschoben werden.
	/**
	* Berechnet das Produkt von zwei angegebenen Brüchen und 
	* liefert das Ergebnis als neuen Bruch zurück.
	*
	* @param a der erste Operand für die Multiplikation
	* @param b der zweite Operand für die Multiplikation
	* @return das Produkt
	*/
	public static Bruch mult(Bruch a, Bruch b) {
	
		return new Bruch(a.zaehler*b.zaehler, a.nenner*b.nenner);
	
	}
	
}

