/**
* Diese Klasse stellt ein Schaf dar. Jedes Schaf produziert eine 
* bestimmte Menge an Wolle pro Monat und hat eine bestimmte Farbe.
*/
public class Sheep {
	
	private String color;
	private int woolPerMonth;
	
	/**
	* Konstruktor: Initialisiert dieses Schaf
	*/
	public Sheep(String color, int woolPerMonth) {
		
		this.color = color;
		this.woolPerMonth = woolPerMonth;
		
	}
	
	/**
	* Kopierkonstruktor: Initialisiert dieses Schaf als 
	* Kopie des angegebenen Schafs.
	*/
	public Sheep(Sheep zuKopieren) {
		
		this(zuKopieren.color, zuKopieren.woolPerMonth);
		
	}
	
	@Override
	/**
	* Die equals-Methode: Überprüft die Gleichheit mit einem anderen 
	* Objekt. Diese Methode kann - muss aber nicht - für die
	* Implementierung der gefragten Klassen benutzt werden.
	* @param o Ein Objekt mit dem dieses Schaf verglichen werden soll
	* @return true, wenn das angegebene Objekt o ein Schaf mit 
	* den gleichen Attributen ist, wie dieses Schaf, sonst false.
	*/
	public boolean equals(Object o) {
		
		if (o == null || o.getClass() != Sheep.class) {
			
			return false;
			
		}
		
		Sheep s = (Sheep) o;
		
		return s.color.equals(this.color) && s.woolPerMonth == this.woolPerMonth;
		
	}
	
	@Override
	/**
	* Die hashCode-Methode, die den Hashcode dieses Schafs liefert. 
	* @return der Hashcode dieses Schafs.
	*/
	public int hashCode() {
		
		return color.hashCode() + woolPerMonth;
		
	}
	
	@Override
	/**
	* Liefert eine lesbare Repräsentation dieses Schafs mit 
	* Farbe und Wolle pro Monat. 
	* Beispiel:
	* #1, white, woolPerMonth = 2
	* @return eine lesbare Repräsentation dieses Schafs
	*/
	public String toString() {
	
		return color + ", woolPerMonth = " + woolPerMonth;
	
	}
	
}
