public class Bruch {
	
	private int zaehler;
	private int nenner;
	
	/**
	* Konstruktor: Initialisiert diesen Bruch. 
	* Vorbedingung: Nenner darf nicht 0 sein.
	*/
	public Bruch(int z, int n) {
	
		this.zaehler = z;
		this.nenner = n;
		
		this.reduce();
	
	}
	
	//kein Kopierkonstruktor notwendig
	
	/**
	* @return eine lesbare Repräsentation dieses Bruchs.
	*/
	public String toString() {
		
		return this.zaehler + "/" + this.nenner;
		
	}
	
	/**
	* kürzt diesen Bruch.
	*/
	private void reduce() {
		
		int ggt = Euklid.ggt(this.zaehler, this.nenner);
		ggt *= this.nenner < 0 ? -1 : 1;
		this.zaehler/=ggt;
		this.nenner/=ggt;
		
	}
	
	//beste Möglichkeit (Brüche sind unveränderbar).
	/**
	* Berechnet das Produkt von diesem Bruch und einem angegeben Bruch und 
	* liefert das Ergebnis als neuen Bruch zurück.
	*
	* @param b der zweite Operand für die Multiplikation
	* @return das Produkt
	*/
	public Bruch mult(Bruch b) {
	
		return new Bruch(this.zaehler*b.zaehler, this.nenner*b.nenner);
	
	}
	
	//Variante 1: Objekt ist veränderbar.
	//globale Seiteneffekte möglich!
	/**
	* Berechnet das Produkt von diesem Bruch und einem angegeben Bruch.
	* Dabei wird dieser Bruch zum Ergebnis der Multiplikation. (Diese
	* Operation ändert dieses Bruch-Objekt.)
	*
	* @param b der zweite Operand für die Multiplikation
	*/
	/*
	public void mult(Bruch b) {
	
		 this.zaehler*=b.zaehler;
		 this.nenner*=b.nenner;
	
	}
	*/
	
	/**
	* @return der Double-Wert dieses Bruchs.
	*/
	public double toDouble() {
	
		return (double)this.zaehler/this.nenner;
	
	}
	
	/**
	* Vergleicht diesen Bruch mit einem angegebenen Bruch.
	* @param vergleichsbruch Der Bruch mit dem dieser Bruch
	* verglichen wird.
	* @return true, wenn der double-Wert dieses Bruchs kleiner ist,
	* als jener des angegebenen Bruchs, sonst false.
	*/
	public boolean kleiner(Bruch vergleichsbruch) {
	
		return this.toDouble() < vergleichsbruch.toDouble();
	
	}
	
	
	//Variante 2: mit static-Methode
	//nicht auf dieses Objekt bezogen, daher static. Prozeduraler Stil. 
	//Methode könnte abgesehen von der Sichtbarkeit der Objektvariablen
	//auch in andere Klassen verschoben werden.
	/**
	* Berechnet das Produkt von zwei angegebenen Brüchen und 
	* liefert das Ergebnis als neuen Bruch zurück.
	*
	* @param a der erste Operand für die Multiplikation
	* @param b der zweite Operand für die Multiplikation
	* @return das Produkt
	*/
	public static Bruch mult(Bruch a, Bruch b) {
	
		return new Bruch(a.zaehler*b.zaehler, a.nenner*b.nenner);
	
	}
	
}

