import java.util.Stack;

public interface Operation {
    
    /**
     * Führt eine Operation auf dem Operanden-Stack aus.
     * @param stack Der Operanden-Stack
     * @throws OperationException, wenn die Operation fehlschlägt
     */
    void execute(Stack<Double> stack);
    
}

/*****************************************************************************/

class AddOperation implements Operation {

    @Override
    public void execute(Stack<Double> stack) {
        
        if(stack.size() < 2){ throw new OperationException("zu wenig Operanden am Stack!"); }
        
        double y = stack.pop();
        double x = stack.pop();
        
        double result = x + y;
        stack.push(result);
        
    }
}

class SubtractOperation implements Operation {

    @Override
    public void execute(Stack<Double> stack) {
        
        if(stack.size() < 2){ throw new OperationException("zu wenig Operanden am Stack!"); }
        
        double y = stack.pop();
        double x = stack.pop();
        
        double result = x - y;
        stack.push(result);
        
    }
}

class MultiplyOperation implements Operation {

    @Override
    public void execute(Stack<Double> stack) {
        
        if(stack.size() < 2){ throw new OperationException("zu wenig Operanden am Stack!"); }
        
        double y = stack.pop();
        double x = stack.pop();
        
        double result = x * y;
        stack.push(result);
        
    }
}

class DivideOperation implements Operation {

    @Override
    public void execute(Stack<Double> stack) {
        
        if(stack.size() < 2){ throw new OperationException("zu wenig Operanden am Stack!"); }
        double y = stack.pop();
        double x = stack.pop();

        if(Math.abs(y) < 1E-8){ throw new OperationException("Division durch 0"); }
        
        double result = x / y;
        stack.push(result);
        
    }
}

class SinOperation implements Operation {

    @Override
    public void execute(Stack<Double> stack) {
        
        double x = stack.pop();
        stack.push(Math.sin(x));
        
    }
}

class EurOperation implements Operation {
    
    private String currency;
    
    public EurOperation(String currency){ this.currency = currency; }

    @Override
    public void execute(Stack<Double> stack) {
        
        double x = stack.pop();
        if(currency.equals("ats")){ stack.push(x * 13.7603); }
        else if(currency.equals("gbp")){ stack.push(x * 0.8413); }
        
    }
}